@@ -1020,15 +1020,47 @@ class QueryBuilder:
 
         if "filters" in query:
             if not pipeline:
-                lookup_filters = {
-                    field: value
-                    for field, value in query["filters"].items()
-                    if list(value.keys())[0][0] != "$"
-                }
+                # Extract potential relation field names from filters, supporting
+                # logical operators ($or/$and) and dot-notation (e.g., "company.name").
+                def extract_relation_candidates(filters_dict):
+                    relation_names = set()
 
-                if list(lookup_filters.keys()):
+                    def walk(node):
+                        if isinstance(node, dict):
+                            for k, v in node.items():
+                                if k in ("$or", "$and"):
+                                    # Value can be a list of conditions or a nested dict
+                                    if isinstance(v, list):
+                                        for item in v:
+                                            walk(item)
+                                    else:
+                                        walk(v)
+                                else:
+                                    # Field key: take root before dot and strip _id/_ids
+                                    if (
+                                        isinstance(k, str)
+                                        and k
+                                        and not k.startswith("$")
+                                    ):
+                                        root = k.split(".")[0]
+                                        root = re.sub(r"(_ids|_id)$", "", root)
+                                        if root:
+                                            relation_names.add(root)
+                                    # Continue walking nested structures like
+                                    # {"company": {"name": {"$containsi": "x"}}}
+                                    walk(v)
+                        elif isinstance(node, list):
+                            for item in node:
+                                walk(item)
+                        # Primitives are ignored
+
+                    walk(filters_dict)
+                    return list(relation_names)
+
+                relation_candidates = extract_relation_candidates(query["filters"])
+                if relation_candidates:
                     populate_from_filters = self.get_count_lookup_relations(
-                        list(lookup_filters.keys())
+                        relation_candidates
                     )
                     pipeline.extend(populate_from_filters)
 
